import{a as e,n as t,r as n,t as r}from"./isArray-BfeOG1E2.js";import{c as i,i as a,s as o}from"./_MapCache-CODy_DtT.js";import{_ as s,a as c,d as l,f as u,g as d,h as f,i as p,l as ee,m,n as h,o as te,r as g,t as _,u as v}from"./_baseFor-Cojpjrzx.js";var y=Object.create,ne=function(){function e(){}return function(t){if(!i(t))return{};if(y)return y(t);e.prototype=t;var n=new e;return e.prototype=void 0,n}}();function re(e,t,n){switch(n.length){case 0:return e.call(t);case 1:return e.call(t,n[0]);case 2:return e.call(t,n[0],n[1]);case 3:return e.call(t,n[0],n[1],n[2])}return e.apply(t,n)}function b(e,t){var n=-1,r=e.length;for(t||=Array(r);++n<r;)t[n]=e[n];return t}var x=800,S=16,C=Date.now;function w(e){var t=0,n=0;return function(){var r=C(),i=S-(r-n);if(n=r,i>0){if(++t>=x)return arguments[0]}else t=0;return e.apply(void 0,arguments)}}function T(e){return function(){return e}}var E=w(d?function(e,t){return d(e,`toString`,{configurable:!0,enumerable:!1,value:T(t),writable:!0})}:s),ie=Object.prototype.hasOwnProperty;function D(e,t,n){var r=e[t];(!(ie.call(e,t)&&a(r,n))||n===void 0&&!(t in e))&&m(e,t,n)}function O(e,t,n,r){var i=!n;n||={};for(var a=-1,o=t.length;++a<o;){var s=t[a],c=r?r(n[s],e[s],s,n,e):void 0;c===void 0&&(c=e[s]),i?m(n,s,c):D(n,s,c)}return n}var k=Math.max;function ae(e,t,n){return t=k(t===void 0?e.length-1:t,0),function(){for(var r=arguments,i=-1,a=k(r.length-t,0),o=Array(a);++i<a;)o[i]=r[t+i];i=-1;for(var s=Array(t+1);++i<t;)s[i]=r[i];return s[t]=n(o),re(e,this,s)}}function oe(e,t){return E(ae(e,t,s),e+``)}function A(e,t,n){if(!i(n))return!1;var r=typeof t;return(r==`number`?u(n)&&f(t,n.length):r==`string`&&t in n)?a(n[t],e):!1}function se(e){return oe(function(t,n){var r=-1,i=n.length,a=i>1?n[i-1]:void 0,o=i>2?n[2]:void 0;for(a=e.length>3&&typeof a==`function`?(i--,a):void 0,o&&A(n[0],n[1],o)&&(a=i<3?void 0:a,i=1),t=Object(t);++r<i;){var s=n[r];s&&e(t,s,r,a)}return t})}function ce(e){var t=[];if(e!=null)for(var n in Object(e))t.push(n);return t}var j=Object.prototype.hasOwnProperty;function M(e){if(!i(e))return ce(e);var t=l(e),n=[];for(var r in e)r==`constructor`&&(t||!j.call(e,r))||n.push(r);return n}function N(e){return u(e)?c(e,!0):M(e)}var P=p(Object.getPrototypeOf,Object),F=`[object Object]`,I=Function.prototype,L=Object.prototype,R=I.toString,z=L.hasOwnProperty,B=R.call(Object);function V(e){if(!t(e)||n(e)!=F)return!1;var r=P(e);if(r===null)return!0;var i=z.call(r,`constructor`)&&r.constructor;return typeof i==`function`&&i instanceof i&&R.call(i)==B}var H=typeof exports==`object`&&exports&&!exports.nodeType&&exports,U=H&&typeof module==`object`&&module&&!module.nodeType&&module,W=U&&U.exports===H?e.Buffer:void 0,G=W?W.allocUnsafe:void 0;function K(e,t){if(t)return e.slice();var n=e.length,r=G?G(n):new e.constructor(n);return e.copy(r),r}function q(e){var t=new e.constructor(e.byteLength);return new h(t).set(new h(e)),t}function J(e,t){var n=t?q(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)}function Y(e){return typeof e.constructor==`function`&&!l(e)?ne(P(e)):{}}function X(e,t,n){(n!==void 0&&!a(e[t],n)||n===void 0&&!(t in e))&&m(e,t,n)}function le(e){return t(e)&&u(e)}function Z(e,t){if(!(t===`constructor`&&typeof e[t]==`function`)&&t!=`__proto__`)return e[t]}function ue(e){return O(e,N(e))}function Q(e,t,n,a,s,c,l){var u=Z(e,n),d=Z(t,n),f=l.get(d);if(f){X(e,n,f);return}var p=c?c(u,d,n+``,e,t,l):void 0,m=p===void 0;if(m){var h=r(d),g=!h&&ee(d),_=!h&&!g&&te(d);p=d,h||g||_?r(u)?p=u:le(u)?p=b(u):g?(m=!1,p=K(d,!0)):_?(m=!1,p=J(d,!0)):p=[]:V(d)||v(d)?(p=u,v(u)?p=ue(u):(!i(u)||o(u))&&(p=Y(d))):m=!1}m&&(l.set(d,p),s(p,d,a,c,l),l.delete(d)),X(e,n,p)}function $(e,t,n,r,a){e!==t&&_(t,function(o,s){if(a||=new g,i(o))Q(e,t,s,n,$,r,a);else{var c=r?r(Z(e,s),o,s+``,e,t,a):void 0;c===void 0&&(c=o),X(e,s,c)}},N)}export{K as a,se as c,D as d,b as f,q as i,A as l,Y as n,P as o,J as r,N as s,$ as t,O as u};