import{a as e,r as t,t as n}from"./isArray-BfeOG1E2.js";import{a as r,n as i,o as a}from"./_MapCache-CODy_DtT.js";import{a as o,d as s,f as c,i as l}from"./_baseFor-Cojpjrzx.js";var u=r(e,`WeakMap`),d=l(Object.keys,Object),f=Object.prototype.hasOwnProperty;function p(e){if(!s(e))return d(e);var t=[];for(var n in Object(e))f.call(e,n)&&n!=`constructor`&&t.push(n);return t}function m(e){return c(e)?o(e):p(e)}function h(e,t){for(var n=-1,r=t.length,i=e.length;++n<r;)e[i+n]=t[n];return e}function g(e,t){for(var n=-1,r=e==null?0:e.length,i=0,a=[];++n<r;){var o=e[n];t(o,n,e)&&(a[i++]=o)}return a}function _(){return[]}var v=Object.prototype.propertyIsEnumerable,y=Object.getOwnPropertySymbols,b=y?function(e){return e==null?[]:(e=Object(e),g(y(e),function(t){return v.call(e,t)}))}:_;function x(e,t,r){var i=t(e);return n(e)?i:h(i,r(e))}function S(e){return x(e,m,b)}var C=r(e,`DataView`),w=r(e,`Promise`),T=r(e,`Set`),E=`[object Map]`,D=`[object Object]`,O=`[object Promise]`,k=`[object Set]`,A=`[object WeakMap]`,j=`[object DataView]`,M=a(C),N=a(i),P=a(w),F=a(T),I=a(u),L=t;(C&&L(new C(new ArrayBuffer(1)))!=j||i&&L(new i)!=E||w&&L(w.resolve())!=O||T&&L(new T)!=k||u&&L(new u)!=A)&&(L=function(e){var n=t(e),r=n==D?e.constructor:void 0,i=r?a(r):``;if(i)switch(i){case M:return j;case N:return E;case P:return O;case F:return k;case I:return A}return n});var R=L;export{_ as a,b as i,S as n,h as o,x as r,m as s,R as t};