import{a as e,n as t,o as n,r,t as i}from"./isArray-BfeOG1E2.js";import{a,n as o,r as s,s as c,t as l}from"./_MapCache-CODy_DtT.js";function u(e){return e}var d=function(){try{var e=a(Object,`defineProperty`);return e({},``,{}),e}catch{}}(),ee=9007199254740991,te=/^(?:0|[1-9]\d*)$/;function f(e,t){var n=typeof e;return t??=ee,!!t&&(n==`number`||n!=`symbol`&&te.test(e))&&e>-1&&e%1==0&&e<t}function ne(e,t,n){t==`__proto__`&&d?d(e,t,{configurable:!0,enumerable:!0,value:n,writable:!0}):e[t]=n}var re=9007199254740991;function p(e){return typeof e==`number`&&e>-1&&e%1==0&&e<=re}function ie(e){return e!=null&&p(e.length)&&!c(e)}var ae=Object.prototype;function m(e){var t=e&&e.constructor;return e===(typeof t==`function`&&t.prototype||ae)}function oe(e,t){for(var n=-1,r=Array(e);++n<e;)r[n]=t(n);return r}var se=`[object Arguments]`;function h(e){return t(e)&&r(e)==se}var g=Object.prototype,ce=g.hasOwnProperty,le=g.propertyIsEnumerable,_=h(function(){return arguments}())?h:function(e){return t(e)&&ce.call(e,`callee`)&&!le.call(e,`callee`)};function ue(){return!1}var v=typeof exports==`object`&&exports&&!exports.nodeType&&exports,y=v&&typeof module==`object`&&module&&!module.nodeType&&module,b=y&&y.exports===v?e.Buffer:void 0,x=(b?b.isBuffer:void 0)||ue,S=`[object Arguments]`,C=`[object Array]`,w=`[object Boolean]`,T=`[object Date]`,E=`[object Error]`,D=`[object Function]`,O=`[object Map]`,k=`[object Number]`,A=`[object Object]`,j=`[object RegExp]`,M=`[object Set]`,N=`[object String]`,P=`[object WeakMap]`,F=`[object ArrayBuffer]`,I=`[object DataView]`,L=`[object Float32Array]`,R=`[object Float64Array]`,z=`[object Int8Array]`,B=`[object Int16Array]`,V=`[object Int32Array]`,H=`[object Uint8Array]`,U=`[object Uint8ClampedArray]`,de=`[object Uint16Array]`,fe=`[object Uint32Array]`,W={};W[L]=W[R]=W[z]=W[B]=W[V]=W[H]=W[U]=W[de]=W[fe]=!0,W[S]=W[C]=W[F]=W[w]=W[I]=W[T]=W[E]=W[D]=W[O]=W[k]=W[A]=W[j]=W[M]=W[N]=W[P]=!1;function pe(e){return t(e)&&p(e.length)&&!!W[r(e)]}function G(e){return function(t){return e(t)}}var K=typeof exports==`object`&&exports&&!exports.nodeType&&exports,q=K&&typeof module==`object`&&module&&!module.nodeType&&module,J=q&&q.exports===K&&n.process,Y=function(){try{return q&&q.require&&q.require(`util`).types||J&&J.binding&&J.binding(`util`)}catch{}}(),X=Y&&Y.isTypedArray,Z=X?G(X):pe,me=Object.prototype.hasOwnProperty;function he(e,t){var n=i(e),r=!n&&_(e),a=!n&&!r&&x(e),o=!n&&!r&&!a&&Z(e),s=n||r||a||o,c=s?oe(e.length,String):[],l=c.length;for(var u in e)(t||me.call(e,u))&&!(s&&(u==`length`||a&&(u==`offset`||u==`parent`)||o&&(u==`buffer`||u==`byteLength`||u==`byteOffset`)||f(u,l)))&&c.push(u);return c}function ge(e,t){return function(n){return e(t(n))}}function _e(){this.__data__=new s,this.size=0}function Q(e){var t=this.__data__,n=t.delete(e);return this.size=t.size,n}function ve(e){return this.__data__.get(e)}function ye(e){return this.__data__.has(e)}var be=200;function xe(e,t){var n=this.__data__;if(n instanceof s){var r=n.__data__;if(!o||r.length<be-1)return r.push([e,t]),this.size=++n.size,this;n=this.__data__=new l(r)}return n.set(e,t),this.size=n.size,this}function $(e){var t=this.__data__=new s(e);this.size=t.size}$.prototype.clear=_e,$.prototype.delete=Q,$.prototype.get=ve,$.prototype.has=ye,$.prototype.set=xe;var Se=e.Uint8Array;function Ce(e){return function(t,n,r){for(var i=-1,a=Object(t),o=r(t),s=o.length;s--;){var c=o[e?s:++i];if(n(a[c],c,a)===!1)break}return t}}var we=Ce();export{u as _,he as a,G as c,m as d,ie as f,d as g,f as h,ge as i,x as l,ne as m,Se as n,Z as o,p,$ as r,Y as s,we as t,_ as u};